@@ -632,6 +632,9 @@ def _jma_true_color_reproduction(img_data, platform=None):
                 "goes-18": np.array([[1.1629, 0.1539, -0.2175],
                                      [-0.0252, 0.8725, 0.1300],
                                      [-0.0204, -0.1100, 1.0633]]),
+                "goes-19": np.array([[0.9481, 0.3706, -0.2194],
+                                     [-0.0150, 0.8605, 0.1317],
+                                     [-0.0174, -0.1009, 1.0512]]),
 
                 "mtg-i1": np.array([[0.9007, 0.2086, -0.0100],
                                     [-0.0475, 1.0662, -0.0414],
