@@ -1,4 +1,4 @@
 """Functions and classes related to MultiScene functionality."""
 
-from ._blend_funcs import stack, timeseries  # noqa
+from ._blend_funcs import stack, temporal_rgb, timeseries  # noqa
 from ._multiscene import MultiScene  # noqa
