@@ -557,24 +557,16 @@ def load_readers(filenames=None, reader=None, reader_kwargs=None):
     reader, filenames, remaining_filenames = _get_reader_and_filenames(reader, filenames)
     (reader_kwargs, reader_kwargs_without_filter) = _get_reader_kwargs(reader, reader_kwargs)
 
+    if reader_kwargs is None:
+        reader_kwargs = {}
+
     for idx, reader_configs in enumerate(configs_for_reader(reader)):
-        if isinstance(filenames, dict):
-            readers_files = set(filenames[reader[idx]])
-        else:
-            readers_files = remaining_filenames
-
-        try:
-            reader_instance = load_reader(
-                    reader_configs,
-                    **reader_kwargs[None if reader is None else reader[idx]])
-        except (KeyError, IOError, yaml.YAMLError) as err:
-            LOG.info("Cannot use %s", str(reader_configs))
-            LOG.debug(str(err))
+        readers_files = _get_readers_files(filenames, reader, idx, remaining_filenames)
+        reader_instance = _get_reader_instance(reader, reader_configs, idx, reader_kwargs)
+        if reader_instance is None or not readers_files:
+            # Reader initiliasation failed or no files were given
             continue
 
-        if not readers_files:
-            # we weren't given any files for this reader
-            continue
         loadables = reader_instance.select_files_from_pathnames(readers_files)
         if loadables:
             reader_instance.create_storage_items(
@@ -582,6 +574,7 @@ def load_readers(filenames=None, reader=None, reader_kwargs=None):
                     fh_kwargs=reader_kwargs_without_filter[None if reader is None else reader[idx]])
             reader_instances[reader_instance.name] = reader_instance
             remaining_filenames -= set(loadables)
+
         if not remaining_filenames:
             break
 
@@ -590,6 +583,32 @@ def load_readers(filenames=None, reader=None, reader_kwargs=None):
     return reader_instances
 
 
+def _get_readers_files(filenames, reader, idx, remaining_filenames):
+    if isinstance(filenames, dict):
+        return set(filenames[reader[idx]])
+    return remaining_filenames
+
+
+def _get_reader_instance(reader, reader_configs, idx, reader_kwargs):
+    reader_instance = None
+    try:
+        reader_instance = load_reader(
+            reader_configs,
+            **reader_kwargs[None if reader is None else reader[idx]])
+    except (KeyError, IOError) as err:
+        LOG.info("Cannot use %s", str(reader_configs))
+        LOG.debug(str(err))
+    except yaml.constructor.ConstructorError as err:
+        _log_yaml_error(reader_configs, err)
+
+    return reader_instance
+
+
+def _log_yaml_error(reader_configs, err):
+    LOG.error("Problem with %s", str(reader_configs))
+    LOG.error(str(err))
+
+
 def _early_exit(filenames, reader):
     if not filenames and not reader:
         # used for an empty Scene
