@@ -44,70 +44,67 @@ class NC_ABI_L1B(NC_ABI_BASE):
 
     def get_dataset(self, key, info):
         """Load a dataset."""
-        logger.debug('Reading in get_dataset %s.', key['name'])
+        logger.debug("Reading in get_dataset %s.", key["name"])
 
         # For raw cal, don't apply scale and offset, return raw file counts
-        if key['calibration'] == 'counts':
-            radiances = self.nc['Rad'].copy()
+        if key["calibration"] == "counts":
+            radiances = self.nc["Rad"].copy()
+            radiances = self._adjust_coords(radiances, "Rad")
         else:
-            radiances = self['Rad']
+            radiances = self["Rad"]
 
         # mapping of calibration types to calibration functions
         cal_dictionary = {
-            'reflectance': self._vis_calibrate,
-            'brightness_temperature': self._ir_calibrate,
-            'radiance': self._rad_calibrate,
-            'counts': self._raw_calibrate,
+            "reflectance": self._vis_calibrate,
+            "brightness_temperature": self._ir_calibrate,
+            "radiance": self._rad_calibrate,
+            "counts": self._raw_calibrate,
         }
-
-        try:
-            func = cal_dictionary[key['calibration']]
-            res = func(radiances)
-        except KeyError:
-            raise ValueError("Unknown calibration '{}'".format(key['calibration']))
+        func = cal_dictionary[key["calibration"]]
+        res = func(radiances)
 
         # convert to satpy standard units
-        if res.attrs['units'] == '1' and key['calibration'] != 'counts':
+        if res.attrs["units"] == "1" and key["calibration"] != "counts":
             res *= 100
-            res.attrs['units'] = '%'
+            res.attrs["units"] = "%"
 
         self._adjust_attrs(res, key)
         return res
 
     def _adjust_attrs(self, data, key):
-        data.attrs.update({'platform_name': self.platform_name,
-                          'sensor': self.sensor})
+        data.attrs.update({"platform_name": self.platform_name,
+                          "sensor": self.sensor})
         # Add orbital parameters
         projection = self.nc["goes_imager_projection"]
-        data.attrs['orbital_parameters'] = {
-            'projection_longitude': float(projection.attrs['longitude_of_projection_origin']),
-            'projection_latitude': float(projection.attrs['latitude_of_projection_origin']),
-            'projection_altitude': float(projection.attrs['perspective_point_height']),
-            'satellite_nominal_latitude': float(self['nominal_satellite_subpoint_lat']),
-            'satellite_nominal_longitude': float(self['nominal_satellite_subpoint_lon']),
-            'satellite_nominal_altitude': float(self['nominal_satellite_height']) * 1000.,
-            'yaw_flip': bool(self['yaw_flip_flag']),
+        data.attrs["orbital_parameters"] = {
+            "projection_longitude": float(projection.attrs["longitude_of_projection_origin"]),
+            "projection_latitude": float(projection.attrs["latitude_of_projection_origin"]),
+            "projection_altitude": float(projection.attrs["perspective_point_height"]),
+            "satellite_nominal_latitude": float(self["nominal_satellite_subpoint_lat"]),
+            "satellite_nominal_longitude": float(self["nominal_satellite_subpoint_lon"]),
+            "satellite_nominal_altitude": float(self["nominal_satellite_height"]) * 1000.,
+            "yaw_flip": bool(self["yaw_flip_flag"]),
         }
         data.attrs.update(key.to_dict())
         # remove attributes that could be confusing later
         # if calibration type is raw counts, we leave them in
-        if key['calibration'] != 'counts':
-            data.attrs.pop('_FillValue', None)
-            data.attrs.pop('scale_factor', None)
-            data.attrs.pop('add_offset', None)
-        data.attrs.pop('_Unsigned', None)
-        data.attrs.pop('ancillary_variables', None)  # Can't currently load DQF
+        if key["calibration"] != "counts":
+            data.attrs.pop("_FillValue", None)
+            data.attrs.pop("scale_factor", None)
+            data.attrs.pop("add_offset", None)
+        data.attrs.pop("_Unsigned", None)
+        data.attrs.pop("ancillary_variables", None)  # Can't currently load DQF
         # although we could compute these, we'd have to update in calibration
-        data.attrs.pop('valid_range', None)
+        data.attrs.pop("valid_range", None)
         # add in information from the filename that may be useful to the user
-        for attr in ('observation_type', 'scene_abbr', 'scan_mode', 'platform_shortname', 'suffix'):
+        for attr in ("observation_type", "scene_abbr", "scan_mode", "platform_shortname", "suffix"):
             if attr in self.filename_info:
                 data.attrs[attr] = self.filename_info[attr]
         # copy global attributes to metadata
-        for attr in ('scene_id', 'orbital_slot', 'instrument_ID', 'production_site', 'timeline_ID'):
+        for attr in ("scene_id", "orbital_slot", "instrument_ID", "production_site", "timeline_ID"):
             data.attrs[attr] = self.nc.attrs.get(attr)
         # only include these if they are present
-        for attr in ('fusion_args',):
+        for attr in ("fusion_args",):
             if attr in self.nc.attrs:
                 data.attrs[attr] = self.nc.attrs[attr]
 
@@ -128,23 +125,23 @@ class NC_ABI_L1B(NC_ABI_BASE):
         """
         res = data
         res.attrs = data.attrs
-        res.attrs['units'] = '1'
-        res.attrs['long_name'] = 'Raw Counts'
-        res.attrs['standard_name'] = 'counts'
+        res.attrs["units"] = "1"
+        res.attrs["long_name"] = "Raw Counts"
+        res.attrs["standard_name"] = "counts"
         return res
 
     def _vis_calibrate(self, data):
         """Calibrate visible channels to reflectance."""
-        solar_irradiance = self['esun']
-        esd = self["earth_sun_distance_anomaly_in_AU"].astype(float)
+        solar_irradiance = self["esun"]
+        esd = self["earth_sun_distance_anomaly_in_AU"]
 
         factor = np.pi * esd * esd / solar_irradiance
 
-        res = data * factor
+        res = data * np.float32(factor)
         res.attrs = data.attrs
-        res.attrs['units'] = '1'
-        res.attrs['long_name'] = 'Bidirectional Reflectance'
-        res.attrs['standard_name'] = 'toa_bidirectional_reflectance'
+        res.attrs["units"] = "1"
+        res.attrs["long_name"] = "Bidirectional Reflectance"
+        res.attrs["standard_name"] = "toa_bidirectional_reflectance"
         return res
 
     def _get_minimum_radiance(self, data):
@@ -166,11 +163,11 @@ class NC_ABI_L1B(NC_ABI_BASE):
 
         if self.clip_negative_radiances:
             min_rad = self._get_minimum_radiance(data)
-            data = data.clip(min=min_rad)
+            data = data.clip(min=data.dtype.type(min_rad))
 
         res = (fk2 / np.log(fk1 / data + 1) - bc1) / bc2
         res.attrs = data.attrs
-        res.attrs['units'] = 'K'
-        res.attrs['long_name'] = 'Brightness Temperature'
-        res.attrs['standard_name'] = 'toa_brightness_temperature'
+        res.attrs["units"] = "K"
+        res.attrs["long_name"] = "Brightness Temperature"
+        res.attrs["standard_name"] = "toa_brightness_temperature"
         return res
