@@ -15,8 +15,7 @@
 
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
-Reader for the ATMS SDR format.
+"""Reader for the ATMS SDR format.
 
 A reader for Advanced Technology Microwave Sounder (ATMS) SDR data as it
 e.g. comes out of the CSPP package for processing Direct Readout data.
@@ -46,8 +45,8 @@ from satpy.utils import get_legacy_chunk_size
 LOG = logging.getLogger(__name__)
 
 CHUNK_SIZE = get_legacy_chunk_size()
-ATMS_CHANNEL_NAMES = ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10',
-                      '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22']
+ATMS_CHANNEL_NAMES = ["1", "2", "3", "4", "5", "6", "7", "8", "9", "10",
+                      "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22"]
 
 
 class ATMS_SDR_FileHandler(JPSS_SDR_FileHandler):
@@ -55,18 +54,18 @@ class ATMS_SDR_FileHandler(JPSS_SDR_FileHandler):
 
     def __init__(self, filename, filename_info, filetype_info, **kwargs):
         """Initialize file handler."""
-        self.datasets = os.path.basename(filename).split('_')[0].split('-')
+        self.datasets = os.path.basename(filename).split("_")[0].split("-")
         super().__init__(filename, filename_info, filetype_info, **kwargs)
 
     def __getitem__(self, key):
         """Get item for given key."""
         val = self.file_content[key]
         if isinstance(val, h5py.Dataset):
-            dset = h5py.File(self.filename, 'r')[key]
+            dset = h5py.File(self.filename, "r")[key]
             if dset.ndim == 3:
                 dset_data = da.from_array(dset, chunks=CHUNK_SIZE)
                 attrs = self._attrs_cache.get(key, dset.attrs)
-                return xr.DataArray(dset_data, dims=['y', 'x', 'z'], attrs=attrs)
+                return xr.DataArray(dset_data, dims=["y", "x", "z"], attrs=attrs)
 
         return super().__getitem__(key)
 
@@ -78,11 +77,11 @@ class ATMS_SDR_FileHandler(JPSS_SDR_FileHandler):
             return None
 
     def _get_scans_per_granule(self, dataset_group):
-        number_of_granules_path = 'Data_Products/{dataset_group}/{dataset_group}_Aggr/attr/AggregateNumberGranules'
+        number_of_granules_path = "Data_Products/{dataset_group}/{dataset_group}_Aggr/attr/AggregateNumberGranules"
         nb_granules_path = number_of_granules_path.format(dataset_group=DATASET_KEYS[dataset_group])
         scans = []
         for granule in range(self[nb_granules_path]):
-            scans_path = 'Data_Products/{dataset_group}/{dataset_group}_Gran_{granule}/attr/N_Number_Of_Scans'
+            scans_path = "Data_Products/{dataset_group}/{dataset_group}_Gran_{granule}/attr/N_Number_Of_Scans"
             scans_path = scans_path.format(dataset_group=DATASET_KEYS[dataset_group], granule=granule)
             scans.append(self[scans_path])
         return scans
@@ -99,15 +98,15 @@ class ATMS_SDR_FileHandler(JPSS_SDR_FileHandler):
         scans actually sensed of course.
 
         """
-        dataset_group = [ds_group for ds_group in ds_info['dataset_groups'] if ds_group in self.datasets]
+        dataset_group = [ds_group for ds_group in ds_info["dataset_groups"] if ds_group in self.datasets]
         if not dataset_group:
             return
 
         dataset_group = dataset_group[0]
-        ds_info['dataset_group'] = dataset_group
+        ds_info["dataset_group"] = dataset_group
         var_path = self._generate_file_key(dataset_id, ds_info)
 
-        ch_index = self._get_atms_channel_index(ds_info['name'])
+        ch_index = self._get_atms_channel_index(ds_info["name"])
         data = self.concatenate_dataset(dataset_group, var_path, channel_index=ch_index)
         data = self.mask_fill_values(data, ds_info)
 
