@@ -17,7 +17,7 @@
 # type: ignore
 """ScatSat-1 L2B Reader, distributed by Eumetsat in HDF5 format."""
 
-from datetime import datetime
+import datetime as dt
 
 import h5py
 
@@ -34,8 +34,10 @@ class SCATSAT1L2BFileHandler(BaseFileHandler):
         self.h5f = h5py.File(self.filename, "r")
         h5data = self.h5f["science_data"]
 
-        self.filename_info["start_time"] = datetime.strptime(h5data.attrs["Range Beginning Date"], "%Y-%jT%H:%M:%S.%f")
-        self.filename_info["end_time"] = datetime.strptime(h5data.attrs["Range Ending Date"], "%Y-%jT%H:%M:%S.%f")
+        self.filename_info["start_time"] = dt.datetime.strptime(
+            h5data.attrs["Range Beginning Date"], "%Y-%jT%H:%M:%S.%f")
+        self.filename_info["end_time"] = dt.datetime.strptime(
+            h5data.attrs["Range Ending Date"], "%Y-%jT%H:%M:%S.%f")
 
         self.lons = None
         self.lats = None
