@@ -119,8 +119,13 @@ from satpy.readers.seviri_base import (
     SATNUM,
     VISIR_NUM_COLUMNS,
     VISIR_NUM_LINES,
+    CalibParams,
+    GsicsCoefficients,
+    MeirinkCoefficients,
+    NominalCoefficients,
     NoValidOrbitParams,
     OrbitPolynomialFinder,
+    ScanParams,
     SEVIRICalibrationHandler,
     add_scanline_acq_time,
     calculate_area_extent,
@@ -618,43 +623,56 @@ class NativeMSGFileHandler(BaseFileHandler):
     def calibrate(self, data, dataset_id):
         """Calibrate the data."""
         tic = dt.datetime.now()
-        channel_name = dataset_id["name"]
-        calib = SEVIRICalibrationHandler(
-            platform_id=self.platform_id,
-            channel_name=channel_name,
-            coefs=self._get_calib_coefs(channel_name),
-            calib_mode=self.calib_mode,
-            scan_time=self.observation_start_time
-        )
+        calib = self._get_calibration_handler(dataset_id)
         res = calib.calibrate(data, dataset_id["calibration"])
         logger.debug("Calibration time " + str(dt.datetime.now() - tic))
         return res
 
+    def _get_calibration_handler(self, dataset_id):
+        channel_name = dataset_id["name"]
+        calib_params = CalibParams(
+            mode=self.calib_mode.upper(),
+            internal_coefs=self._get_calib_coefs(channel_name),
+            external_coefs=self.ext_calib_coefs,
+            radiance_type=self._get_radiance_type(channel_name)
+        )
+        scan_params = ScanParams(self.platform_id, channel_name,
+                                 self.observation_start_time)
+        return SEVIRICalibrationHandler(calib_params, scan_params)
+
     def _get_calib_coefs(self, channel_name):
         """Get coefficients for calibration from counts to radiance."""
-        # even though all the channels may not be present in the file,
-        # the header does have calibration coefficients for all the channels
-        # hence, this channel index needs to refer to full channel list
-        band_idx = list(CHANNEL_NAMES.values()).index(channel_name)
-
+        band_idx = self._get_band_index(channel_name)
         coefs_nominal = self.header["15_DATA_HEADER"][
             "RadiometricProcessing"]["Level15ImageCalibration"]
         coefs_gsics = self.header["15_DATA_HEADER"][
             "RadiometricProcessing"]["MPEFCalFeedback"]
+        nominal_coefs = NominalCoefficients(
+            channel_name, coefs_nominal["CalSlope"][band_idx], coefs_nominal["CalOffset"][band_idx]
+        )
+        gsics_coefs = GsicsCoefficients(
+            channel_name, coefs_gsics["GSICSCalCoeff"][band_idx], coefs_gsics["GSICSOffsetCount"][band_idx]
+        )
+        meirink_coefs = MeirinkCoefficients(
+            self.platform_id, channel_name, self.observation_start_time
+        )
+        return create_coef_dict(
+            nominal_coefs,
+            gsics_coefs,
+            meirink_coefs
+        )
+
+    def _get_band_index(self, channel_name):
+        # even though all the channels may not be present in the file,
+        # the header does have calibration coefficients for all the channels
+        # hence, this channel index needs to refer to full channel list
+        return list(CHANNEL_NAMES.values()).index(channel_name)
+
+    def _get_radiance_type(self, channel_name):
+        band_idx = self._get_band_index(channel_name)
         radiance_types = self.header["15_DATA_HEADER"]["ImageDescription"][
             "Level15ImageProduction"]["PlannedChanProcessing"]
-        return create_coef_dict(
-            coefs_nominal=(
-                coefs_nominal["CalSlope"][band_idx],
-                coefs_nominal["CalOffset"][band_idx]
-            ),
-            coefs_gsics=(
-                coefs_gsics["GSICSCalCoeff"][band_idx],
-                coefs_gsics["GSICSOffsetCount"][band_idx]
-            ),
-            ext_coefs=self.ext_calib_coefs.get(channel_name, {}),
-            radiance_type=radiance_types[band_idx]
-        )
+        return radiance_types[band_idx]
 
     def _add_scanline_acq_time(self, dataset, dataset_id):
         """Add scanline acquisition time to the given dataset."""
