@@ -21,7 +21,7 @@ import numpy as np
 import pytest
 import xarray as xr
 
-from satpy.composites.spectral import GreenCorrector, HybridGreen, NDVIHybridGreen, SpectralBlender
+from satpy.composites.spectral import HybridGreen, NDVIHybridGreen, SpectralBlender
 from satpy.tests.utils import CustomScheduler
 
 
@@ -67,68 +67,56 @@ class TestSpectralComposites:
         data = res.compute()
         np.testing.assert_allclose(data, 0.23)
 
-    def test_green_corrector(self):
-        """Test the deprecated class for green corrections."""
-        comp = GreenCorrector("blended_channel", fractions=(0.85, 0.15), prerequisites=(0.51, 0.85),
-                              standard_name="toa_bidirectional_reflectance")
-        res = comp((self.c01, self.c03))
-        assert isinstance(res, xr.DataArray)
-        assert isinstance(res.data, da.Array)
-        assert res.attrs["name"] == "blended_channel"
-        assert res.attrs["standard_name"] == "toa_bidirectional_reflectance"
-        data = res.compute()
-        np.testing.assert_allclose(data, 0.23)
-
 
 class TestNdviHybridGreenCompositor:
     """Test NDVI-weighted hybrid green correction of green band."""
 
     def setup_method(self):
         """Initialize channels."""
+        coord_val = [1.0, 2.0]
         self.c01 = xr.DataArray(
             da.from_array(np.array([[0.25, 0.30], [0.20, 0.30]], dtype=np.float32), chunks=25),
-            dims=("y", "x"), attrs={"name": "C02"})
+            dims=("y", "x"), coords=[coord_val, coord_val], attrs={"name": "C02"})
         self.c02 = xr.DataArray(
             da.from_array(np.array([[0.25, 0.30], [0.25, 0.35]], dtype=np.float32), chunks=25),
-            dims=("y", "x"), attrs={"name": "C03"})
+            dims=("y", "x"), coords=[coord_val, coord_val], attrs={"name": "C03"})
         self.c03 = xr.DataArray(
             da.from_array(np.array([[0.35, 0.35], [0.28, 0.65]], dtype=np.float32), chunks=25),
-            dims=("y", "x"), attrs={"name": "C04"})
+            dims=("y", "x"), coords=[coord_val, coord_val], attrs={"name": "C04"})
 
     def test_ndvi_hybrid_green(self):
         """Test General functionality with linear scaling from ndvi to blend fraction."""
-        with dask.config.set(scheduler=CustomScheduler(max_computes=1)):
+        with dask.config.set(scheduler=CustomScheduler(max_computes=0)):
             comp = NDVIHybridGreen("ndvi_hybrid_green", limits=(0.15, 0.05), prerequisites=(0.51, 0.65, 0.85),
                                    standard_name="toa_bidirectional_reflectance")
 
             # Test General functionality with linear strength (=1.0)
             res = comp((self.c01, self.c02, self.c03))
-            assert isinstance(res, xr.DataArray)
-            assert isinstance(res.data, da.Array)
-            assert res.attrs["name"] == "ndvi_hybrid_green"
-            assert res.attrs["standard_name"] == "toa_bidirectional_reflectance"
-            data = res.values
+        assert isinstance(res, xr.DataArray)
+        assert isinstance(res.data, da.Array)
+        assert res.attrs["name"] == "ndvi_hybrid_green"
+        assert res.attrs["standard_name"] == "toa_bidirectional_reflectance"
+        data = res.values
         np.testing.assert_array_almost_equal(data, np.array([[0.2633, 0.3071], [0.2115, 0.3420]]), decimal=4)
 
     def test_ndvi_hybrid_green_dtype(self):
         """Test that the datatype is not altered by the compositor."""
-        with dask.config.set(scheduler=CustomScheduler(max_computes=1)):
+        with dask.config.set(scheduler=CustomScheduler(max_computes=0)):
             comp = NDVIHybridGreen("ndvi_hybrid_green", limits=(0.15, 0.05), prerequisites=(0.51, 0.65, 0.85),
                                    standard_name="toa_bidirectional_reflectance")
-            res = comp((self.c01, self.c02, self.c03)).compute()
+            res = comp((self.c01, self.c02, self.c03))
         assert res.data.dtype == np.float32
 
     def test_nonlinear_scaling(self):
         """Test non-linear scaling using `strength` term."""
-        with dask.config.set(scheduler=CustomScheduler(max_computes=1)):
+        with dask.config.set(scheduler=CustomScheduler(max_computes=0)):
             comp = NDVIHybridGreen("ndvi_hybrid_green", limits=(0.15, 0.05), strength=2.0,
                                    prerequisites=(0.51, 0.65, 0.85),
                                    standard_name="toa_bidirectional_reflectance")
-
             res = comp((self.c01, self.c02, self.c03))
-            res_np = res.data.compute()
-            assert res.dtype == res_np.dtype
-            assert res.dtype == np.float32
+        res_np = res.data.compute()
+        assert res.dtype == res_np.dtype
+        assert res.dtype == np.float32
         np.testing.assert_array_almost_equal(res.data, np.array([[0.2646, 0.3075], [0.2120, 0.3471]]), decimal=4)
 
     def test_invalid_strength(self):
@@ -136,3 +124,17 @@ class TestNdviHybridGreenCompositor:
         with pytest.raises(ValueError, match="Expected strength greater than 0.0, got 0.0."):
             _ = NDVIHybridGreen("ndvi_hybrid_green", strength=0.0, prerequisites=(0.51, 0.65, 0.85),
                                 standard_name="toa_bidirectional_reflectance")
+
+    def test_with_slightly_mismatching_coord_input(self):
+        """Test the case where an input (typically the red band) has a slightly different coordinate.
+
+        If match_data_arrays is called correctly, the coords will be aligned and the array will have the expected shape.
+
+        """
+        comp = NDVIHybridGreen("ndvi_hybrid_green", limits=(0.15, 0.05), prerequisites=(0.51, 0.65, 0.85),
+                               standard_name="toa_bidirectional_reflectance")
+
+        c02_bad_shape = self.c02.copy()
+        c02_bad_shape.coords["y"] = [1.1, 2.]
+        res = comp((self.c01, c02_bad_shape, self.c03))
+        assert res.shape == (2, 2)
