@@ -36,7 +36,7 @@ def step_impl_create_scene_one_dataset(context):
 
     from satpy import Scene
     scn = Scene()
-    scn["MyDataset"] = DataArray([[1, 2], [3, 4]], dims=['y', 'x'])
+    scn["MyDataset"] = DataArray([[1, 2], [3, 4]], dims=["y", "x"])
     context.scene = scn
 
 
@@ -48,7 +48,7 @@ def step_impl_scene_show(context):
         context (behave.runner.Context): Test context
 
     """
-    with patch('trollimage.xrimage.XRImage.show') as mock_show:
+    with patch("trollimage.xrimage.XRImage.show") as mock_show:
         context.scene.show("MyDataset")
         mock_show.assert_called_once_with()
 
@@ -100,8 +100,8 @@ def step_impl_create_scene_two_datasets(context):
 
     from satpy import Scene
     scn = Scene()
-    scn["MyDataset"] = DataArray([[1, 2], [3, 4]], dims=['y', 'x'])
-    scn["MyDataset2"] = DataArray([[5, 6], [7, 8]], dims=['y', 'x'])
+    scn["MyDataset"] = DataArray([[1, 2], [3, 4]], dims=["y", "x"])
+    scn["MyDataset2"] = DataArray([[5, 6], [7, 8]], dims=["y", "x"])
     context.scene = scn
 
 
