@@ -42,29 +42,29 @@ class FakeHDF5FileHandler2(FakeHDF5FileHandler):
     def get_test_content(self, filename, filename_info, filetype_info):
         """Mimic reader input file content."""
         file_content = {
-            '/attr/PlatformShortName': 'GCOM-W1',
-            '/attr/SensorShortName': 'AMSR2',
-            '/attr/StartOrbitNumber': '22210',
-            '/attr/StopOrbitNumber': '22210',
+            "/attr/PlatformShortName": "GCOM-W1",
+            "/attr/SensorShortName": "AMSR2",
+            "/attr/StartOrbitNumber": "22210",
+            "/attr/StopOrbitNumber": "22210",
         }
-        k = 'Geophysical Data'
+        k = "Geophysical Data"
         file_content[k] = DEFAULT_FILE_DATA[:, :]
-        file_content[k + '/shape'] = (DEFAULT_FILE_SHAPE[0], DEFAULT_FILE_SHAPE[1])
-        file_content[k + '/attr/UNIT'] = 'K'
-        file_content[k + '/attr/SCALE FACTOR'] = 1
+        file_content[k + "/shape"] = (DEFAULT_FILE_SHAPE[0], DEFAULT_FILE_SHAPE[1])
+        file_content[k + "/attr/UNIT"] = "K"
+        file_content[k + "/attr/SCALE FACTOR"] = 1
 
-        k = 'Latitude of Observation Point'
+        k = "Latitude of Observation Point"
         file_content[k] = DEFAULT_FILE_DATA[:, :]
-        file_content[k + '/shape'] = (DEFAULT_FILE_SHAPE[0], DEFAULT_FILE_SHAPE[1])
-        file_content[k + '/attr/UNIT'] = 'deg'
-        file_content[k + '/attr/SCALE FACTOR'] = 1
-        k = 'Longitude of Observation Point'
+        file_content[k + "/shape"] = (DEFAULT_FILE_SHAPE[0], DEFAULT_FILE_SHAPE[1])
+        file_content[k + "/attr/UNIT"] = "deg"
+        file_content[k + "/attr/SCALE FACTOR"] = 1
+        k = "Longitude of Observation Point"
         file_content[k] = DEFAULT_FILE_DATA[:, :]
-        file_content[k + '/shape'] = (DEFAULT_FILE_SHAPE[0], DEFAULT_FILE_SHAPE[1])
-        file_content[k + '/attr/UNIT'] = 'deg'
-        file_content[k + '/attr/SCALE FACTOR'] = 1
+        file_content[k + "/shape"] = (DEFAULT_FILE_SHAPE[0], DEFAULT_FILE_SHAPE[1])
+        file_content[k + "/attr/UNIT"] = "deg"
+        file_content[k + "/attr/SCALE FACTOR"] = 1
 
-        convert_file_content_to_data_array(file_content, dims=('dim_0', 'dim_1'))
+        convert_file_content_to_data_array(file_content, dims=("dim_0", "dim_1"))
         return file_content
 
 
@@ -78,9 +78,9 @@ class TestAMSR2L2Reader(unittest.TestCase):
         from satpy._config import config_search_paths
         from satpy.readers.amsr2_l1b import AMSR2L1BFileHandler
         from satpy.readers.amsr2_l2 import AMSR2L2FileHandler
-        self.reader_configs = config_search_paths(os.path.join('readers', self.yaml_file))
+        self.reader_configs = config_search_paths(os.path.join("readers", self.yaml_file))
         # http://stackoverflow.com/questions/12219967/how-to-mock-a-base-class-with-python-mock-library
-        self.p = mock.patch.object(AMSR2L2FileHandler, '__bases__', (FakeHDF5FileHandler2,
+        self.p = mock.patch.object(AMSR2L2FileHandler, "__bases__", (FakeHDF5FileHandler2,
                                                                      AMSR2L1BFileHandler))
         self.fake_handler = self.p.start()
         self.p.is_local = True
@@ -94,29 +94,27 @@ class TestAMSR2L2Reader(unittest.TestCase):
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
-            'GW1AM2_202004160129_195B_L2SNSSWLB3300300.h5',
+            "GW1AM2_202004160129_195B_L2SNSSWLB3300300.h5",
         ])
-        self.assertEqual(len(loadables), 1)
+        assert len(loadables) == 1
         r.create_filehandlers(loadables)
         # make sure we have some files
-        self.assertTrue(r.file_handlers)
+        assert r.file_handlers
 
     def test_load_basic(self):
         """Test loading of basic channels."""
         from satpy.readers import load_reader
         r = load_reader(self.reader_configs)
         loadables = r.select_files_from_pathnames([
-            'GW1AM2_202004160129_195B_L2SNSSWLB3300300.h5',
+            "GW1AM2_202004160129_195B_L2SNSSWLB3300300.h5",
         ])
-        self.assertEqual(len(loadables), 1)
+        assert len(loadables) == 1
         r.create_filehandlers(loadables)
-        ds = r.load(['ssw'])
-        self.assertEqual(len(ds), 1)
+        ds = r.load(["ssw"])
+        assert len(ds) == 1
         for d in ds.values():
-            self.assertTupleEqual(d.shape, (DEFAULT_FILE_SHAPE[0], int(DEFAULT_FILE_SHAPE[1])))
-            self.assertIn('area', d.attrs)
-            self.assertIsNotNone(d.attrs['area'])
-            self.assertTupleEqual(d.attrs['area'].lons.shape,
-                                  (DEFAULT_FILE_SHAPE[0], DEFAULT_FILE_SHAPE[1]))
-            self.assertTupleEqual(d.attrs['area'].lats.shape,
-                                  (DEFAULT_FILE_SHAPE[0], DEFAULT_FILE_SHAPE[1]))
+            assert d.shape == (DEFAULT_FILE_SHAPE[0], int(DEFAULT_FILE_SHAPE[1]))
+            assert "area" in d.attrs
+            assert d.attrs["area"] is not None
+            assert d.attrs["area"].lons.shape == (DEFAULT_FILE_SHAPE[0], DEFAULT_FILE_SHAPE[1])
+            assert d.attrs["area"].lats.shape == (DEFAULT_FILE_SHAPE[0], DEFAULT_FILE_SHAPE[1])
