@@ -135,29 +135,46 @@ class TestSunZenithCorrector:
         assert res.dtype == res_np.dtype
         assert "y" not in res.coords
         assert "x" not in res.coords
+        if as_32bit:
+            assert res.dtype == np.float32
 
-    def test_basic_lims_not_provided(self, sunz_ds1):
+    @pytest.mark.parametrize("dtype", [np.float32, np.float64])
+    def test_basic_lims_not_provided(self, sunz_ds1, dtype):
         """Test custom limits when SZA isn't provided."""
         from satpy.modifiers.geometry import SunZenithCorrector
         comp = SunZenithCorrector(name="sza_test", modifiers=tuple(), correction_limit=90)
-        res = comp((sunz_ds1,), test_attr="test")
-        np.testing.assert_allclose(res.values, np.array([[66.853262, 68.168939], [66.30742, 67.601493]]))
+        res = comp((sunz_ds1.astype(dtype),), test_attr="test")
+        expected = np.array([[66.853262, 68.168939], [66.30742, 67.601493]], dtype=dtype)
+        values = res.values
+        np.testing.assert_allclose(values, expected, rtol=1e-5)
+        assert res.dtype == dtype
+        assert values.dtype == dtype
 
+    @pytest.mark.parametrize("dtype", [np.float32, np.float64])
     @pytest.mark.parametrize("data_arr", [lazy_fixture("sunz_ds1"), lazy_fixture("sunz_ds1_stacked")])
-    def test_basic_default_provided(self, data_arr, sunz_sza):
+    def test_basic_default_provided(self, data_arr, sunz_sza, dtype):
         """Test default limits when SZA is provided."""
         from satpy.modifiers.geometry import SunZenithCorrector
         comp = SunZenithCorrector(name="sza_test", modifiers=tuple())
-        res = comp((data_arr, sunz_sza), test_attr="test")
-        np.testing.assert_allclose(res.values, np.array([[22.401667, 22.31777], [22.437503, 22.353533]]))
+        res = comp((data_arr.astype(dtype), sunz_sza.astype(dtype)), test_attr="test")
+        expected = np.array([[22.401667, 22.31777], [22.437503, 22.353533]], dtype=dtype)
+        values = res.values
+        np.testing.assert_allclose(values, expected)
+        assert res.dtype == dtype
+        assert values.dtype == dtype
 
+    @pytest.mark.parametrize("dtype", [np.float32, np.float64])
     @pytest.mark.parametrize("data_arr", [lazy_fixture("sunz_ds1"), lazy_fixture("sunz_ds1_stacked")])
-    def test_basic_lims_provided(self, data_arr, sunz_sza):
+    def test_basic_lims_provided(self, data_arr, sunz_sza, dtype):
         """Test custom limits when SZA is provided."""
         from satpy.modifiers.geometry import SunZenithCorrector
         comp = SunZenithCorrector(name="sza_test", modifiers=tuple(), correction_limit=90)
-        res = comp((data_arr, sunz_sza), test_attr="test")
-        np.testing.assert_allclose(res.values, np.array([[66.853262, 68.168939], [66.30742, 67.601493]]))
+        res = comp((data_arr.astype(dtype), sunz_sza.astype(dtype)), test_attr="test")
+        expected = np.array([[66.853262, 68.168939], [66.30742, 67.601493]], dtype=dtype)
+        values = res.values
+        np.testing.assert_allclose(values, expected, rtol=1e-5)
+        assert res.dtype == dtype
+        assert values.dtype == dtype
 
     def test_imcompatible_areas(self, sunz_ds2, sunz_sza):
         """Test sunz correction on incompatible areas."""
@@ -179,18 +196,28 @@ class TestSunZenithReducer:
         cls.custom = SunZenithReducer(name="sza_reduction_test_custom", modifiers=tuple(),
                                       correction_limit=70, max_sza=95, strength=3.0)
 
-    def test_default_settings(self, sunz_ds1, sunz_sza):
+    @pytest.mark.parametrize("dtype", [np.float32, np.float64])
+    def test_default_settings(self, sunz_ds1, sunz_sza, dtype):
         """Test default settings with sza data available."""
-        res = self.default((sunz_ds1, sunz_sza), test_attr="test")
-        np.testing.assert_allclose(res.values,
-                                   np.array([[0.02916261, 0.02839063], [0.02949383, 0.02871911]]),
-                                   rtol=1e-5)
+        res = self.default((sunz_ds1.astype(dtype), sunz_sza.astype(dtype)), test_attr="test")
+        expected = np.array([[0.02916261, 0.02839063], [0.02949383, 0.02871911]], dtype=dtype)
+        assert res.dtype == dtype
+        values = res.values
+        assert values.dtype == dtype
+        np.testing.assert_allclose(values,
+                                   expected,
+                                   rtol=2e-5)
 
-    def test_custom_settings(self, sunz_ds1, sunz_sza):
+    @pytest.mark.parametrize("dtype", [np.float32, np.float64])
+    def test_custom_settings(self, sunz_ds1, sunz_sza, dtype):
         """Test custom settings with sza data available."""
-        res = self.custom((sunz_ds1, sunz_sza), test_attr="test")
-        np.testing.assert_allclose(res.values,
-                                   np.array([[0.01041319, 0.01030033], [0.01046164, 0.01034834]]),
+        res = self.custom((sunz_ds1.astype(dtype), sunz_sza.astype(dtype)), test_attr="test")
+        expected = np.array([[0.01041319, 0.01030033], [0.01046164, 0.01034834]], dtype=dtype)
+        assert res.dtype == dtype
+        values = res.values
+        assert values.dtype == dtype
+        np.testing.assert_allclose(values,
+                                   expected,
                                    rtol=1e-5)
 
     def test_invalid_max_sza(self, sunz_ds1, sunz_sza):
@@ -502,6 +529,7 @@ class TestPSPRayleighReflectance:
                               })
         return input_band, red_band, angle1, angle1, angle1, angle1
 
+    @pytest.mark.parametrize("dtype", [np.float32, np.float64])
     @pytest.mark.parametrize(
         ("name", "wavelength", "resolution", "aerosol_type", "reduce_lim_low", "reduce_lim_high", "reduce_strength",
          "exp_mean", "exp_unique"),
@@ -521,7 +549,7 @@ class TestPSPRayleighReflectance:
         ]
     )
     def test_rayleigh_corrector(self, name, wavelength, resolution, aerosol_type, reduce_lim_low, reduce_lim_high,
-                                reduce_strength, exp_mean, exp_unique):
+                                reduce_strength, exp_mean, exp_unique, dtype):
         """Test PSPRayleighReflectance with fake data."""
         from satpy.modifiers.atmosphere import PSPRayleighReflectance
         ray_cor = PSPRayleighReflectance(name=name, atmosphere="us-standard", aerosol_types=aerosol_type,
@@ -535,42 +563,48 @@ class TestPSPRayleighReflectance:
         assert ray_cor.attrs["reduce_strength"] == reduce_strength
 
         input_band, red_band, *_ = self._create_test_data(name, wavelength, resolution)
-        res = ray_cor([input_band, red_band])
+        res = ray_cor([input_band.astype(dtype), red_band.astype(dtype)])
 
         assert isinstance(res, xr.DataArray)
         assert isinstance(res.data, da.Array)
+        assert res.dtype == dtype
 
         data = res.values
         unique = np.unique(data[~np.isnan(data)])
         np.testing.assert_allclose(np.nanmean(data), exp_mean, rtol=1e-5)
         assert data.shape == (3, 5)
         np.testing.assert_allclose(unique, exp_unique, rtol=1e-5)
+        assert data.dtype == dtype
 
+    @pytest.mark.parametrize("dtype", [np.float32, np.float64])
     @pytest.mark.parametrize("as_optionals", [False, True])
-    def test_rayleigh_with_angles(self, as_optionals):
+    def test_rayleigh_with_angles(self, as_optionals, dtype):
         """Test PSPRayleighReflectance with angles provided."""
         from satpy.modifiers.atmosphere import PSPRayleighReflectance
         aerosol_type = "rayleigh_only"
         ray_cor = PSPRayleighReflectance(name="B01", atmosphere="us-standard", aerosol_types=aerosol_type)
-        prereqs, opt_prereqs = self._get_angles_prereqs_and_opts(as_optionals)
+        prereqs, opt_prereqs = self._get_angles_prereqs_and_opts(as_optionals, dtype)
         with mock.patch("satpy.modifiers.atmosphere.get_angles") as get_angles:
             res = ray_cor(prereqs, opt_prereqs)
         get_angles.assert_not_called()
 
         assert isinstance(res, xr.DataArray)
         assert isinstance(res.data, da.Array)
+        assert res.dtype == dtype
 
         data = res.values
         unique = np.unique(data[~np.isnan(data)])
         np.testing.assert_allclose(unique, np.array([-75.0, -37.71298492, 31.14350754]), rtol=1e-5)
         assert data.shape == (3, 5)
+        assert data.dtype == dtype
 
-    def _get_angles_prereqs_and_opts(self, as_optionals):
+    def _get_angles_prereqs_and_opts(self, as_optionals, dtype):
         wavelength = (0.45, 0.47, 0.49)
         resolution = 1000
         input_band, red_band, *angles = self._create_test_data("B01", wavelength, resolution)
-        prereqs = [input_band, red_band]
+        prereqs = [input_band.astype(dtype), red_band.astype(dtype)]
         opt_prereqs = []
+        angles = [a.astype(dtype) for a in angles]
         if as_optionals:
             opt_prereqs = angles
         else:
