@@ -74,7 +74,7 @@ local_id_keys_config = {"name": {
 real_import = builtins.__import__
 
 
-@pytest.fixture()
+@pytest.fixture
 def viirs_file(tmp_path, monkeypatch):
     """Create a dummy viirs file."""
     filename = "SVI01_npp_d20120225_t1801245_e1802487_b01708_c20120226002130255476_noaa_ops.h5"
@@ -85,7 +85,7 @@ def viirs_file(tmp_path, monkeypatch):
     return filename
 
 
-@pytest.fixture()
+@pytest.fixture
 def atms_file(tmp_path, monkeypatch):
     """Create a dummy atms file."""
     filename = "SATMS_j01_d20221220_t0910240_e0921356_b26361_c20221220100456348770_cspp_dev.h5"
@@ -258,6 +258,12 @@ class TestReaderLoader(unittest.TestCase):
     Assumes that the VIIRS SDR reader exists and works.
     """
 
+    @pytest.fixture(autouse=True)
+    def inject_fixtures(self, caplog, tmp_path):  # noqa: PT004
+        """Inject caplog to the test class."""
+        self._caplog = caplog
+        self._tmp_path = tmp_path
+
     def setUp(self):
         """Wrap HDF5 file handler with our own fake handler."""
         from satpy.readers.viirs_sdr import VIIRSSDRFileHandler
@@ -439,6 +445,31 @@ class TestReaderLoader(unittest.TestCase):
         assert "abi_l1b" in readers
         assert len(list(readers["abi_l1b"].available_dataset_ids)) == 0
 
+    def test_yaml_error_message(self):
+        """Test that YAML errors are logged properly."""
+        import logging
+
+        import satpy
+        from satpy.readers import load_readers
+
+        reader_config = "reader:\n"
+        reader_config += "  name: nonreader\n"
+        reader_config += "  reader: !!python/name:notapackage.notareader.BadClass\n"
+
+        os.mkdir(self._tmp_path / "readers")
+        reader_fname = self._tmp_path / "readers" / "nonreader.yaml"
+        with open(reader_fname, "w") as fid:
+            fid.write(reader_config)
+
+        filenames = ["foo.bar"]
+        error_message = "No module named 'notapackage'"
+
+        with self._caplog.at_level(logging.ERROR):
+            with satpy.config.set({"config_path": [str(self._tmp_path)]}):
+                with pytest.raises(ValueError, match="No supported files found"):
+                    _ = load_readers(filenames=filenames, reader="nonreader")
+            assert error_message in self._caplog.text
+
 
 class TestFindFilesAndReaders:
     """Test the find_files_and_readers utility function."""
