@@ -43,66 +43,65 @@ pyninjotiff_mock = mock.Mock()
 pyninjotiff_mock.ninjotiff = mock.Mock()
 
 
-@mock.patch.dict(sys.modules, {'pyninjotiff': pyninjotiff_mock, 'pyninjotiff.ninjotiff': pyninjotiff_mock.ninjotiff})
+@mock.patch.dict(sys.modules, {"pyninjotiff": pyninjotiff_mock, "pyninjotiff.ninjotiff": pyninjotiff_mock.ninjotiff})
 class TestNinjoTIFFWriter(unittest.TestCase):
     """The ninjo tiff writer tests."""
 
-    @mock.patch('satpy.writers.ninjotiff.nt', pyninjotiff_mock.ninjotiff)
+    @mock.patch("satpy.writers.ninjotiff.nt", pyninjotiff_mock.ninjotiff)
     def test_init(self):
         """Test the init."""
         from satpy.writers.ninjotiff import NinjoTIFFWriter
-        ninjo_tags = {40000: 'NINJO'}
+        ninjo_tags = {40000: "NINJO"}
         ntw = NinjoTIFFWriter(tags=ninjo_tags)
-        self.assertDictEqual(ntw.tags, ninjo_tags)
+        assert ntw.tags == ninjo_tags
 
-    @mock.patch('satpy.writers.ninjotiff.ImageWriter.save_dataset')
-    @mock.patch('satpy.writers.ninjotiff.nt', pyninjotiff_mock.ninjotiff)
+    @mock.patch("satpy.writers.ninjotiff.ImageWriter.save_dataset")
+    @mock.patch("satpy.writers.ninjotiff.nt", pyninjotiff_mock.ninjotiff)
     def test_dataset(self, iwsd):
         """Test saving a dataset."""
         from satpy.writers.ninjotiff import NinjoTIFFWriter
         ntw = NinjoTIFFWriter()
-        dataset = xr.DataArray([1, 2, 3], attrs={'units': 'K'})
-        with mock.patch('satpy.writers.ninjotiff.convert_units') as uconv:
-            ntw.save_dataset(dataset, physic_unit='CELSIUS')
-            uconv.assert_called_once_with(dataset, 'K', 'CELSIUS')
-        self.assertEqual(iwsd.call_count, 1)
+        dataset = xr.DataArray([1, 2, 3], attrs={"units": "K"})
+        with mock.patch("satpy.writers.ninjotiff.convert_units") as uconv:
+            ntw.save_dataset(dataset, physic_unit="CELSIUS")
+            uconv.assert_called_once_with(dataset, "K", "CELSIUS")
+        assert iwsd.call_count == 1
 
-    @mock.patch('satpy.writers.ninjotiff.ImageWriter.save_dataset')
-    @mock.patch('satpy.writers.ninjotiff.nt', pyninjotiff_mock.ninjotiff)
+    @mock.patch("satpy.writers.ninjotiff.ImageWriter.save_dataset")
+    @mock.patch("satpy.writers.ninjotiff.nt", pyninjotiff_mock.ninjotiff)
     def test_dataset_skip_unit_conversion(self, iwsd):
         """Test saving a dataset without unit conversion."""
         from satpy.writers.ninjotiff import NinjoTIFFWriter
         ntw = NinjoTIFFWriter()
-        dataset = xr.DataArray([1, 2, 3], attrs={'units': 'K'})
-        with mock.patch('satpy.writers.ninjotiff.convert_units') as uconv:
-            ntw.save_dataset(dataset, physic_unit='CELSIUS',
+        dataset = xr.DataArray([1, 2, 3], attrs={"units": "K"})
+        with mock.patch("satpy.writers.ninjotiff.convert_units") as uconv:
+            ntw.save_dataset(dataset, physic_unit="CELSIUS",
                              convert_temperature_units=False)
             uconv.assert_not_called()
-        self.assertEqual(iwsd.call_count, 1)
+        assert iwsd.call_count == 1
 
-    @mock.patch('satpy.writers.ninjotiff.NinjoTIFFWriter.save_dataset')
-    @mock.patch('satpy.writers.ninjotiff.ImageWriter.save_image')
-    @mock.patch('satpy.writers.ninjotiff.nt', pyninjotiff_mock.ninjotiff)
+    @mock.patch("satpy.writers.ninjotiff.NinjoTIFFWriter.save_dataset")
+    @mock.patch("satpy.writers.ninjotiff.ImageWriter.save_image")
+    @mock.patch("satpy.writers.ninjotiff.nt", pyninjotiff_mock.ninjotiff)
     def test_image(self, iwsi, save_dataset):
         """Test saving an image."""
         nt = pyninjotiff_mock.ninjotiff
         nt.reset_mock()
         from satpy.writers.ninjotiff import NinjoTIFFWriter
         ntw = NinjoTIFFWriter()
-        dataset = xr.DataArray([1, 2, 3], attrs={'units': 'K'})
-        img = FakeImage(dataset, 'L')
-        ret = ntw.save_image(img, filename='bla.tif', compute=False)
+        dataset = xr.DataArray([1, 2, 3], attrs={"units": "K"})
+        img = FakeImage(dataset, "L")
+        ret = ntw.save_image(img, filename="bla.tif", compute=False)
         nt.save.assert_called()
-        assert nt.save.mock_calls[0][2]['compute'] is False
-        assert nt.save.mock_calls[0][2]['ch_min_measurement_unit'] < nt.save.mock_calls[0][2]['ch_max_measurement_unit']
+        assert nt.save.mock_calls[0][2]["compute"] is False
+        assert nt.save.mock_calls[0][2]["ch_min_measurement_unit"] < nt.save.mock_calls[0][2]["ch_max_measurement_unit"]
         assert ret == nt.save.return_value
 
     def test_convert_units_self(self):
         """Test that unit conversion to themselves do nothing."""
+        from satpy.tests.utils import make_fake_scene
         from satpy.writers.ninjotiff import convert_units
 
-        from ..utils import make_fake_scene
-
         # ensure that converting from % to itself does not change the data
         sc = make_fake_scene(
                 {"VIS006": np.arange(25, dtype="f4").reshape(5, 5)},
@@ -115,9 +114,8 @@ class TestNinjoTIFFWriter(unittest.TestCase):
     def test_convert_units_temp(self):
         """Test that temperature unit conversions works as expected."""
         # test converting between °C and K
+        from satpy.tests.utils import make_fake_scene
         from satpy.writers.ninjotiff import convert_units
-
-        from ..utils import make_fake_scene
         sc = make_fake_scene(
                 {"IR108": np.arange(25, dtype="f4").reshape(5, 5)},
                 common_attrs={"units": "K"})
@@ -134,9 +132,8 @@ class TestNinjoTIFFWriter(unittest.TestCase):
     def test_convert_units_other(self):
         """Test that other unit conversions are not implemented."""
         # test arbitrary different conversion
+        from satpy.tests.utils import make_fake_scene
         from satpy.writers.ninjotiff import convert_units
-
-        from ..utils import make_fake_scene
         sc = make_fake_scene(
                 {"rain_rate": np.arange(25, dtype="f8").reshape(5, 5)},
                 common_attrs={"units": "millimeter/hour"})
@@ -145,9 +142,9 @@ class TestNinjoTIFFWriter(unittest.TestCase):
         with pytest.raises(NotImplementedError):
             convert_units(ds_in, "millimeter/hour", "m/s")
 
-    @mock.patch('satpy.writers.ninjotiff.NinjoTIFFWriter.save_dataset')
-    @mock.patch('satpy.writers.ninjotiff.ImageWriter.save_image')
-    @mock.patch('satpy.writers.ninjotiff.nt', pyninjotiff_mock.ninjotiff)
+    @mock.patch("satpy.writers.ninjotiff.NinjoTIFFWriter.save_dataset")
+    @mock.patch("satpy.writers.ninjotiff.ImageWriter.save_image")
+    @mock.patch("satpy.writers.ninjotiff.nt", pyninjotiff_mock.ninjotiff)
     def test_P_image_is_uint8(self, iwsi, save_dataset):
         """Test that a P-mode image is converted to uint8s."""
         nt = pyninjotiff_mock.ninjotiff
@@ -155,6 +152,6 @@ class TestNinjoTIFFWriter(unittest.TestCase):
         from satpy.writers.ninjotiff import NinjoTIFFWriter
         ntw = NinjoTIFFWriter()
         dataset = xr.DataArray([1, 2, 3]).astype(int)
-        img = FakeImage(dataset, 'P')
-        ntw.save_image(img, filename='bla.tif', compute=False)
+        img = FakeImage(dataset, "P")
+        ntw.save_image(img, filename="bla.tif", compute=False)
         assert nt.save.mock_calls[0][1][0].data.dtype == np.uint8
