@@ -74,11 +74,13 @@ For images where the pixel value corresponds directly to a physical value,
 NinJo has a functionality to read the corresponding quantity (example:
 brightness temperature or reflectance).  To make this possible, the writer
 adds the tags ``Gradient`` and ``AxisIntercept``.  Those tags are added if
-and only if the image has mode ``L`` or ``LA`` and ``PhysicUnit`` is not set
+and only if the image has mode ``L``, ``P``, or ``LA`` and ``PhysicUnit`` is not set
 to ``"N/A"``.  In other words, to suppress those tags for images with mode
 ``L`` or ``LA`` (for example, for the composite ``vis_with_ir``, where the
 physical interpretation of individual pixels is lost), one should set
 ``PhysicUnit`` to ``"N/A"``, ``"n/a"``, ``"1"``, or ``""`` (empty string).
+If the image has mode ``P``, ``Gradient`` is set to ``1.0`` and ``AxisIntercept``
+to ``0.0`` (as expected by NinJo).
 """
 
 import copy
@@ -204,11 +206,22 @@ class NinJoGeoTIFFWriter(GeoTIFFWriter):
             overviews_minsize=overviews_minsize,
             overviews_resampling=overviews_resampling,
             tags={**(tags or {}), **ninjo_tags},
-            scale_offset_tags=(self.scale_offset_tag_names
-                               if self._check_include_scale_offset(image, PhysicUnit)
-                               else None),
+            scale_offset_tags=self._get_scale_offset_tags(image, PhysicUnit),
             **gdal_opts)
 
+    def _get_scale_offset_tags(self, image, unit):
+        """Get scale offset tags (tuple or dict)."""
+        if self._check_include_scale_offset(image, unit):
+            # image.mode cannot be trusted https://github.com/pytroll/satpy/issues/2300
+            try:
+                mod = image.data.attrs["mode"]
+            except KeyError:
+                mod = image.mode
+            if mod == "P":
+                return dict(zip(self.scale_offset_tag_names, (1, 0)))
+            return self.scale_offset_tag_names
+        return None  # explicit is better than implicit
+
     def _fix_units(self, image, quantity, unit):
         """Adapt units between °C and K.
 
@@ -236,7 +249,7 @@ class NinJoGeoTIFFWriter(GeoTIFFWriter):
 
     def _check_include_scale_offset(self, image, unit):
         """Check if scale-offset tags should be included."""
-        if image.mode.startswith("L") and unit.lower() not in ("n/a", "1", ""):
+        if image.mode[0] in "LP" and unit.lower() not in ("n/a", "1", ""):
             return True
         return False
 
